==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ha-NE.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ha-NE",
  date_format_full => "EEEE, d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Lit",
    "Tal",
    "Lar",
    "Alh",
    "Jum",
    "Asa",
    "Lah"
  ],
  day_format_narrow => [
    "L",
    "T",
    "L",
    "A",
    "J",
    "A",
    "L"
  ],
  day_format_wide => [
    "Litinin",
    "Talata",
    "Laraba",
    "Alhamis",
    "Jumma\N{U+02bc}a",
    "Asabar",
    "Lahadi"
  ],
  day_stand_alone_abbreviated => [
    "Lit",
    "Tal",
    "Lar",
    "Alh",
    "Jum",
    "Asa",
    "Lah"
  ],
  day_stand_alone_narrow => [
    "L",
    "T",
    "L",
    "A",
    "J",
    "A",
    "L"
  ],
  day_stand_alone_wide => [
    "Litinin",
    "Talata",
    "Laraba",
    "Alhamis",
    "Jumma\N{U+02bc}a",
    "Asabar",
    "Lahadi"
  ],
  era_abbreviated => [
    "KHAI",
    "BHAI"
  ],
  era_narrow => [
    "KHAI",
    "BHAI"
  ],
  era_wide => [
    "Kafin haihuwar annab",
    "Bayan haihuwar annab"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Hausa",
  month_format_abbreviated => [
    "Jan",
    "Fab",
    "Mar",
    "Afi",
    "May",
    "Yun",
    "Yul",
    "Agu",
    "Sat",
    "Okt",
    "Nuw",
    "Dis"
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "Y",
    "Y",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "Janairu",
    "Faburairu",
    "Maris",
    "Afirilu",
    "Mayu",
    "Yuni",
    "Yuli",
    "Agusta",
    "Satumba",
    "Oktoba",
    "Nuwamba",
    "Disamba"
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Fab",
    "Mar",
    "Afi",
    "May",
    "Yun",
    "Yul",
    "Agu",
    "Sat",
    "Okt",
    "Nuw",
    "Dis"
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "Y",
    "Y",
    "A",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "Janairu",
    "Faburairu",
    "Maris",
    "Afirilu",
    "Mayu",
    "Yuni",
    "Yuli",
    "Agusta",
    "Satumba",
    "Oktoba",
    "Nuwamba",
    "Disamba"
  ],
  name => "Hausa Niger",
  native_language => "Hausa",
  native_name => "Hausa Nijar",
  native_script => undef,
  native_territory => "Nijar",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Kwata na \N{U+0257}aya",
    "Kwata na biyu",
    "Kwata na uku",
    "Kwata na hu\N{U+0257}u"
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Kwata na \N{U+0257}aya",
    "Kwata na biyu",
    "Kwata na uku",
    "Kwata na hu\N{U+0257}u"
  ],
  script => undef,
  territory => "Niger",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.32.tar.gz: DateTime-Locale-1.32/share/ha-NE.pl <==
{
  am_pm_abbreviated => [
    "SF",
    "YM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E, d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-one" => "'satin' W 'cikin' MMMM",
    "MMMMW-count-other" => "'satin' W 'cikin' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "y MMM d, E",
    yMMMM => "MMMM y",
    yMMMd => "d MMM, y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'sati' w 'cikin' Y",
    "yw-count-other" => "'sati' w 'cikin' Y",
  },
  code => "ha-NE",
  date_format_full => "EEEE d MMMM, y",
  date_format_long => "d MMMM, y",
  date_format_medium => "d MMM, y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} 'da' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Lit",
    "Tal",
    "Lar",
    "Alh",
    "Jum",
    "Asa",
    "Lah",
  ],
  day_format_narrow => [
    "L",
    "T",
    "L",
    "A",
    "J",
    "A",
    "L",
  ],
  day_format_wide => [
    "Litinin",
    "Talata",
    "Laraba",
    "Alhamis",
    "Jumma\N{U+02bc}a",
    "Asabar",
    "Lahadi",
  ],
  day_stand_alone_abbreviated => [
    "Lit",
    "Tal",
    "Lar",
    "Alh",
    "Jum",
    "Asa",
    "Lah",
  ],
  day_stand_alone_narrow => [
    "L",
    "T",
    "L",
    "A",
    "J",
    "A",
    "L",
  ],
  day_stand_alone_wide => [
    "Litinin",
    "Talata",
    "Laraba",
    "Alhamis",
    "Jumma\N{U+02bc}a",
    "Asabar",
    "Lahadi",
  ],
  era_abbreviated => [
    "K.H",
    "BHAI",
  ],
  era_narrow => [
    "K.H",
    "BHAI",
  ],
  era_wide => [
    "Kafin haihuwar annab",
    "Bayan haihuwar annab",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Hausa",
  month_format_abbreviated => [
    "Jan",
    "Fab",
    "Mar",
    "Afi",
    "May",
    "Yun",
    "Yul",
    "Agu",
    "Sat",
    "Okt",
    "Nuw",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "Y",
    "Y",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janairu",
    "Faburairu",
    "Maris",
    "Afirilu",
    "Mayu",
    "Yuni",
    "Yuli",
    "Agusta",
    "Satumba",
    "Oktoba",
    "Nuwamba",
    "Disamba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Fab",
    "Mar",
    "Afi",
    "May",
    "Yun",
    "Yul",
    "Agu",
    "Sat",
    "Okt",
    "Nuw",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "Y",
    "Y",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janairu",
    "Faburairu",
    "Maris",
    "Afirilu",
    "Mayu",
    "Yuni",
    "Yuli",
    "Agusta",
    "Satumba",
    "Oktoba",
    "Nuwamba",
    "Disamba",
  ],
  name => "Hausa Niger",
  native_language => "Hausa",
  native_name => "Hausa Nijar",
  native_script => undef,
  native_territory => "Nijar",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Kwata na \N{U+0257}aya",
    "Kwata na biyu",
    "Kwata na uku",
    "Kwata na hu\N{U+0257}u",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Kwata na \N{U+0257}aya",
    "Kwata na biyu",
    "Kwata na uku",
    "Kwata na hu\N{U+0257}u",
  ],
  script => undef,
  territory => "Niger",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 39,
}
